///////////////////////////////////////////////////
// setmac.h
// 720020-11861
//
// Applied Data Systems
//
// Description
// -----------
// SetMacAddress allows the user to set the MAC address on BitsyX connector boards containing
// the SMSC91C111 chip.
// 
// Requirements
// ------------
// The SMSC91C111 chip must be accessable through PCMCIA slot 1.
//
// Usage
// -----
// There are 3 ways that SetMacAddress can be used: Command line, 
// ADSLOAD.MAC file, or interactively.
//
// 1. Command Line:
//    Example: setmacaddress 11-22-33-44-55-66
//    If a valid MAC address is provided on the command line in the form shown above,
//    it will be written to the chip.  If an invalid parameter is given, the program will
//    exit and print an error message on the debug port.
//
// 2. ADSLOAD.MAC:
//    If no command line parameter is given, SetMacAddress will look for the file "ADSLOAD.MAC"
//    in the current directory.  If it is found, the next MAC address, as well as the lower and
//    upper bound addresses will be read from the file.  If the MAC address is valid and within
//    the given constraints, it will be written to the chip, If an error occurs, the program will
//    terminate and print an error message on the debug port.  Otherwise, the current MAC address
//    will be incremented by one and written back to the chip as the next MAC address to write.
//
//    File format:
//       00-60-0c-00-cc-50
//       00-60-0c-00-00-00
//       00-60-0c-ff-ff-ff
//
//    Line 1 contains the next MAC address to be assigned.
//    Line 2 contains the lower bound of the range of valid MAC addresses.
//    Line 3 contains the upper bound of the range of valid MAC addresses.
//
// 3. Interactive:
//    If no command line parameter is given and ADSLOAD.MAC cannot be found, SetMacAddress will
//    prompt the user to enter a MAC address.  Once a valid MAC address has been entered, the user
//    will have the option of writing it to the chip or quitting without writing.
//
// History
// -------
// 720020-11xx1: December 16, 2004 (jcamann)
//  - Version 1.0 created
///////////////////////////////////////////////////


#define SMC_BASE 				0x300		// offset of SMSC chip
#define PAGE_SIZE 				0x100000 	// 1 page:4KB
#define BUF_LEN		256

VOID SelectBank(USHORT Value);
USHORT ReadReg(USHORT reg);
void WriteReg(USHORT reg, USHORT data);
void SMCChipReset();
BOOL GetMACFromString(UCHAR *buf, UCHAR *MAC);
BOOL GetHexDigit(UCHAR *src, UCHAR *dest);
void IncrementMAC(UCHAR *buf);
BOOL IsMACInRange(UCHAR *NextMac, UCHAR *StartMac, UCHAR *EndMac);
void ReadMACAddress(UCHAR *dest);
void WriteMACAddress(UCHAR *src);
BOOL VerifyMAC(UCHAR *src1, UCHAR *src2);
BOOL GetMACFromFile(FILE *fp, UCHAR *szNextMac, UCHAR *NextMac);
